@@ -123,6 +123,43 @@ class KubeclientConfigTest < MiniTest::Test
     end
   end
 
+  def test_gcp_default_auth
+    Kubeclient::GoogleApplicationDefaultCredentials.expects(:token).returns('token1').once
+    parsed = YAML.safe_load(File.read(config_file('gcpauth.kubeconfig')), [Date, Time])
+    config = Kubeclient::Config.new(parsed, nil)
+    config.context(config.contexts.first)
+  end
+
+  # Each call to .context() obtains a new token, calling .auth_options doesn't change anything.
+  # NOTE: this is not a guarantee, may change, just testing current behavior.
+  def test_gcp_default_auth_renew
+    Kubeclient::GoogleApplicationDefaultCredentials.expects(:token).returns('token1').once
+    parsed = YAML.safe_load(File.read(config_file('gcpauth.kubeconfig')), [Date, Time])
+    config = Kubeclient::Config.new(parsed, nil)
+    context = config.context(config.contexts.first)
+    assert_equal({ bearer_token: 'token1' }, context.auth_options)
+    assert_equal({ bearer_token: 'token1' }, context.auth_options)
+
+    Kubeclient::GoogleApplicationDefaultCredentials.expects(:token).returns('token2').once
+    context2 = config.context(config.contexts.first)
+    assert_equal({ bearer_token: 'token2' }, context2.auth_options)
+    assert_equal({ bearer_token: 'token1' }, context.auth_options)
+  end
+
+  def test_oidc_auth_provider
+    Kubeclient::OIDCAuthProvider.expects(:token)
+                                .with('client-id' => 'fake-client-id',
+                                      'client-secret' => 'fake-client-secret',
+                                      'id-token' => 'fake-id-token',
+                                      'idp-issuer-url' => 'https://accounts.google.com',
+                                      'refresh-token' => 'fake-refresh-token')
+                                .returns('token1')
+                                .once
+    parsed = YAML.safe_load(File.read(config_file('oidcauth.kubeconfig')))
+    config = Kubeclient::Config.new(parsed, nil)
+    config.context(config.contexts.first)
+  end
+
   private
 
   def check_context(context, ssl: true)
